/**
 * Calculates the maturity amount of a Fixed Deposit (FD).
 * @param principal - The initial amount deposited.
 * @param annualInterestRate - The annual interest rate (in percentage).
 * @param totalYears - The total duration of the FD in years.
 * @param compoundingFrequency - The number of times interest is compounded per year.
 * @returns The maturity amount of the FD.
 * @throws Error if any parameter is invalid.
 */
export declare function calculateFD(principal: number, annualInterestRate: number, totalYears: number, compoundingFrequency?: number): number;
/**
 * Calculates the maturity amount of a Recurring Deposit (RD).
 * @param monthlyInvestment - The amount deposited monthly.
 * @param annualInterestRate - The annual interest rate (in percentage).
 * @param totalYears - The total duration of the RD in years.
 * @returns The maturity amount of the RD.
 * @throws Error if any parameter is invalid.
 */
export declare function calculateRD(monthlyInvestment: number, annualInterestRate: number, totalYears: number): number;
